@@ -106,10 +106,13 @@ class ManagementSystemHandler(tornado.web.RequestHandler):
 		logging.debug("\n\n")
 		logging.debug("[+] -- Verify debugging")
 		logging.debug("\n\n")
+		logging.debug("\n [+] -- Request body")
+		logging.debug(self.request.body)
+		logging.debug("\n [+] -- Request arguments")
+		logging.debug(self.request.arguments)
 
 		if self.request.body:
 			logging.debug("\n POST request")
-			logging.debug(self.request.body)
 			data = json.loads(self.request.body)
 			message = json.dumps(data.get("message"))
 			logging.debug(" * Message")
@@ -119,13 +122,15 @@ class ManagementSystemHandler(tornado.web.RequestHandler):
 
 		elif self.request.arguments:
 			logging.debug("\n GET request")
-			logging.debug(self.request.arguments)
 			data = {i:self.get_argument(i) for i in self.request.arguments}
 			message = data.get("message", "{}")
 			logging.debug(" * Message")
 			logging.debug(message)
 			logging.debug(" * Messages type")
 			logging.debug(type(message))
+		else:
+			logging.debug("\n [+] -- Missed request body and arguments")
+			data = {}
 
 		try:
 			# Check if required fields exist
